BarcodeFormat enum
Values
- aztec → const BarcodeFormat
-
const BarcodeFormat(1) - codabar → const BarcodeFormat
-
const BarcodeFormat(2) - code39 → const BarcodeFormat
-
const BarcodeFormat(3) - code93 → const BarcodeFormat
-
const BarcodeFormat(4) - code128 → const BarcodeFormat
-
const BarcodeFormat(5) - dataBar → const BarcodeFormat
-
const BarcodeFormat(6) - dataBarExpanded → const BarcodeFormat
-
const BarcodeFormat(7) - dataMatrix → const BarcodeFormat
-
const BarcodeFormat(8) - ean8 → const BarcodeFormat
-
const BarcodeFormat(9) - ean13 → const BarcodeFormat
-
const BarcodeFormat(10) - itf → const BarcodeFormat
-
const BarcodeFormat(11) - pdf417 → const BarcodeFormat
-
const BarcodeFormat(13) - qrCode → const BarcodeFormat
-
const BarcodeFormat(14) - microQrCode → const BarcodeFormat
-
const BarcodeFormat(15) - rmQrCode → const BarcodeFormat
-
const BarcodeFormat(16) - upcA → const BarcodeFormat
-
const BarcodeFormat(17) - upcE → const BarcodeFormat
-
const BarcodeFormat(18)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BarcodeFormat> - A constant List of the values in this enum, in order of their declaration.