ZxingOptions class
Constructors
-
ZxingOptions({bool tryRotate = false, bool tryInvert = false, bool tryHarder = true, bool tryDownscale = false, int maxNumberOfSymbols = 1, int downscaleFactor = 3, int downscaleThreshold = 500, bool tryCode39ExtendedMode = false, Binarizer binarizer = Binarizer.globalHistogram, Set<BarcodeFormat> formats = const <BarcodeFormat>{BarcodeFormat.qrCode}})
-
const
Properties
-
binarizer
→ Binarizer
-
Determines the method used to convert the image to binary format.
final
-
downscaleFactor
→ int
-
The factor by which to downscale the image when tryDownscale is true.
final
-
downscaleThreshold
→ int
-
The minimum image dimension (in pixels) above which downscaling will be applied.
final
-
formats
→ Set<BarcodeFormat>
-
The barcode formats to scan for.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
maxNumberOfSymbols
→ int
-
Specifies the maximum number of barcodes to detect in a single scan.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
tryCode39ExtendedMode
→ bool
-
If true, enables extended mode for Code 39 format.
final
-
tryDownscale
→ bool
-
If true, the scanner will downscale the image before processing.
final
-
tryHarder
→ bool
-
If true, the scanner will use more advanced decoding techniques.
final
-
tryInvert
→ bool
-
If true, the scanner will attempt to invert the image colors to find a barcode.
final
-
tryRotate
→ bool
-
If true, the scanner will attempt to rotate the image in 90° increments to find a barcode.
final